summaryrefslogtreecommitdiffstats
path: root/vcs/cvsservice/cvspart.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit32b67ac0690de411b26b1d5e715b188c27442248 (patch)
tree43167816a3df6b3a877d71c9a7963ed270dcc8c9 /vcs/cvsservice/cvspart.cpp
parent330c33ab6f97b279737bf9527c9add7bb1475450 (diff)
downloadtdevelop-32b67ac0690de411b26b1d5e715b188c27442248.tar.gz
tdevelop-32b67ac0690de411b26b1d5e715b188c27442248.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'vcs/cvsservice/cvspart.cpp')
-rw-r--r--vcs/cvsservice/cvspart.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/vcs/cvsservice/cvspart.cpp b/vcs/cvsservice/cvspart.cpp
index c95d5e2e..17eb8998 100644
--- a/vcs/cvsservice/cvspart.cpp
+++ b/vcs/cvsservice/cvspart.cpp
@@ -80,8 +80,8 @@ K_EXPORT_COMPONENT_FACTORY( libkdevcvsservice, CvsFactory( data ) )
// class CvsServicePart
///////////////////////////////////////////////////////////////////////////////
-CvsServicePart::CvsServicePart( TQObject *tqparent, const char *name, const TQStringList & )
- : KDevVersionControl( &data, tqparent,
+CvsServicePart::CvsServicePart( TQObject *parent, const char *name, const TQStringList & )
+ : KDevVersionControl( &data, parent,
name ? name : "CvsService" ),
actionCommit( 0 ), actionDiff( 0 ), actionLog( 0 ), actionAnnotate(0), actionAdd( 0 ),
actionAddBinary( 0 ), actionRemove( 0 ), actionUpdate( 0 ),
@@ -283,9 +283,9 @@ void CvsServicePart::projectConfigWidget( KDialogBase *dlg )
///////////////////////////////////////////////////////////////////////////////
-TQWidget* CvsServicePart::newProjectWidget( TQWidget *tqparent )
+TQWidget* CvsServicePart::newProjectWidget( TQWidget *parent )
{
- m_cvsConfigurationForm = new CvsForm( tqparent, "cvsform" );
+ m_cvsConfigurationForm = new CvsForm( parent, "cvsform" );
return m_cvsConfigurationForm;
}
@@ -361,7 +361,7 @@ void CvsServicePart::contextMenu( TQPopupMenu *popup, const Context *context )
id = subMenu->insertItem( actionRemoveFromIgnoreList->text(), this, TQT_SLOT(slotRemoveFromIgnoreList()) );
subMenu->tqsetWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
// Now insert in tqparent menu
popup->insertItem( i18n("CvsService"), subMenu );
// If the current project doesn't support CVS, we don't
@@ -361,7 +361,7 @@ void CvsServicePart::contextMenu( TQPopupMenu *popup, const Context *context )
id = subMenu->insertItem( actionRemoveFromIgnoreList->text(), this, TQT_SLOT(slotRemoveFromIgnoreList()) );
subMenu->tqsetWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
- // Now insert in tqparent menu
+ // Now insert in parent menu
popup->insertItem( i18n("CvsService"), subMenu );
// If the current project doesn't support CVS, we don't